package hayashi.tools.files;

import java.io.File;
import java.io.IOException;

import static org.hamcrest.CoreMatchers.is;
import static org.junit.Assert.*;

import org.junit.Test;

public class DeleteDirTest {

	@Test(expected = IOException.class)
	public void 指定したファイルがないとき() throws Exception {
		File dir = new File("testspace", "FOLDER");
		if (dir.exists()) {
			DeleteDir.delete(dir);
		}
		DeleteDir.delete(dir);
		fail("例外が発生しない");		// 例外が発生しなければ失敗
	}
	
	@Test
	public void 削除対象がファイルのとき() throws IOException {
		File newfile = new File("testspace", "FILE");
		newfile.createNewFile();
		DeleteDir.delete(new File("testspace", "FILE"));
		assertThat(newfile.exists(), is(false));
	}

	@Test
	public void 削除対象が空のフォルダのとき() throws IOException {
		File newdir = new File("testspace", "FOLDER");
		newdir.mkdirs();
		DeleteDir.delete(new File("testspace", "FOLDER"));
		assertThat(newdir.exists(), is(false));
	}

	@Test
	public void 削除対象がNEXTしたフォルダのとき() throws IOException {
		File newdir = new File("testspace", "FOLDER");
		newdir.mkdirs();
		(new File("testspace/FOLDER", "FOLDER")).mkdir();
		(new File("testspace/FOLDER", "FILE")).createNewFile();
		(new File("testspace/FOLDER/FOLDER", "FILE")).createNewFile();
		DeleteDir.delete(new File("testspace", "FOLDER"));
		assertThat(newdir.exists(), is(false));
	}
}
